gocuelang.org/go/mod/modfile Index | Files

package modfile

import "cuelang.org/go/mod/modfile"

Package modfile provides functionality for reading and parsing the CUE module file, cue.mod/module.cue.

WARNING: THIS PACKAGE IS EXPERIMENTAL. ITS API MAY CHANGE AT ANY TIME.

Index

Variables

var ErrNoLanguageVersion = fmt.Errorf("no language version declared in module.cue")

ErrNoLanguageVersion is returned by Parse and ParseNonStrict when a cue.mod/module.cue file lacks the `language.version` field.

Functions

func EarliestClosedSchemaVersion

func EarliestClosedSchemaVersion() string

EarliestClosedSchemaVersion returns the earliest module.cue schema version that excludes unknown fields. Any version declared in a module.cue file should be at least this, because that's when we added the language.version field itself.

func Format

func Format(f *File) ([]byte, error)

Format returns a formatted representation of f in CUE syntax.

Types

type Dep

type Dep = modfiledata.Dep

type File

type File = modfiledata.File

File represents the contents of a cue.mod/module.cue file.

func FixLegacy

func FixLegacy(modfile []byte, filename string) (*File, error)

FixLegacy converts a legacy module.cue file as parsed by ParseLegacy into a format suitable for parsing with Parse. It adds a language.version field and moves all unrecognized fields into custom.legacy.

If there is no module field or it is empty, it is set to "test.example".

If the file already parses OK with ParseNonStrict, it returns the result of that.

func Parse

func Parse(modfile []byte, filename string) (*File, error)

Parse verifies that the module file has correct syntax and follows the schema following the required language.version field. The file name is used for error messages. All dependencies must be specified correctly: with major versions in the module paths and canonical dependency versions.

func ParseLegacy

func ParseLegacy(modfile []byte, filename string) (*File, error)

ParseLegacy parses the legacy version of the module file that only supports the single field "module" and ignores all other fields.

func ParseNonStrict

func ParseNonStrict(modfile []byte, filename string) (*File, error)

ParseNonStrict is like Parse but allows some laxity in the parsing:

The file name is used for error messages.

type Language

type Language = modfiledata.Language

type Source

type Source = modfiledata.Source

Source represents how to transform from a module's source to its actual contents.

Source Files

modfile.go

Version
v0.15.1 (latest)
Published
Nov 21, 2025
Platform
linux/amd64
Imports
16 packages
Last checked
4 months ago

Tools for package owners.